@@ -44,9 +44,11 @@ This module converts returned values from JavaScript thus:
 
 =item * Arrays become Perl array references.
 
-=item * Functions trigger an exception. (TODO: Make those a Perl coderef.)
+=item * “Plain” objects become Perl hash references.
 
-=item * Other JS objects become Perl hash references.
+=item * Functions become Perl code references.
+
+=item * Behaviour is B<UNDEFINED> for other object types.
 
 =back
 
@@ -54,10 +56,10 @@ This module converts returned values from JavaScript thus:
 
 =head1 TYPE CONVERSION: PERL → JAVASCRIPT
 
-Generally speaking, it’s the inverse of JS → Perl, though of course
-since Perl doesn’t differentiate “numeric strings” from “numbers” there’s
-occasional ambiguity. In such cases, behavior is undefined; be sure to
-typecast in JavaScript accordingly!
+Generally speaking, it’s the inverse of JS → Perl, though since Perl doesn’t
+differentiate “numeric strings” from “numbers” there’s occasional ambiguity.
+In such cases, behavior is undefined; be sure to typecast in JavaScript
+accordingly.
 
 =over
 
@@ -66,10 +68,13 @@ primitives.
 
 =item * Perl undef becomes JS null.
 
-=item * Array & hash references become JavaScript arrays and “plain” objects.
+=item * Unblessed array & hash references become JavaScript arrays and
+“plain” objects.
 
 =item * Perl code references become JavaScript functions.
 
+=item * Anything else triggers an exception.
+
 =back
 
 =head1 PLATFORM NOTES
@@ -87,7 +92,7 @@ Pull requests to improve portability are welcome!
 
 use XSLoader;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -126,10 +131,17 @@ Note that no values can be returned directly in this mode of execution.
 
 =head1 LICENSE & COPYRIGHT
 
-Copyright 2019-2021 Gasper Software Consulting.
+Copyright 2022 Gasper Software Consulting.
 
 This library is licensed under the same terms as Perl itself.
 
 =cut
 
+#----------------------------------------------------------------------
+
+sub _wrap_jsfunc {
+    my $jsfunc_obj = $_[0];
+    return sub { $jsfunc_obj->call(@_) };
+}
+
 1;
